Pydoc: module db_apis

Python 3.7.3rc1 [default, GCC 8.3.0]
Linux-4.19.0-4-amd64-x86_64-with-glibc2.28
Module Index : Topics : Keywords

db_apis | index /home/misha/Проекты/lingtypology/lingtypology/lingtypology/db_apis.py

`APIs for work Wals and Phoible. Requires Internet connection.`

Modules
`` |  |
pandas | urllib.request |  |

Classes
`` |  | builtins.object Wals
class Wals(builtins.object)
`` | `Wals(features) Wals show_citation: bool, default True Whether to print the citation.`
| Methods defined here: __init__(self, features) `init features: list of strings Wals pages you want to use.` get_df(self) `Get data from Wals in pandas.DataFrame format. Returns pandas.DataFrame Headers: 'wals code', 'language', 'genus', 'family', 'area', 'coordinates', [[name of the page1]], [[name of the page2]], ... Names of the pages start with '_'.` get_json(self) `Get data from Wals in JSON format. Returns dict Keys: 'wals code', 'language', 'genus', 'family', 'area', 'coordinates', [[name of the page1]], [[name of the page2]], ... Names of the pages start with '_'.` Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)` Data and other attributes defined here: show_citation = True